@@ -17,6 +17,10 @@ from .ls_files import LsFilesCommand
 from .ls_tree import LsTreeCommand
 from .worktree import WorktreeCommand
 from .stash import StashCommand
+from .diff import DiffCommand
+from .show import ShowCommand
+from .diff_tree import DiffTreeCommand
+from .reset import ResetCommand
 __all__ = [
     "BaseCommand",
     "InitCommand",
@@ -34,4 +38,8 @@ __all__ = [
     "LsTreeCommand",
     "WorktreeCommand",
     "StashCommand",
+    "DiffCommand",
+    "ShowCommand",
+    "DiffTreeCommand",
+    "ResetCommand",
 ]
