@@ -128,17 +128,27 @@ class WorktreeCommand(BaseCommand):
                 self.repo._set_branch_commit(branch_name, commit_hash)
                 print(f"Created branch '{branch_name}'")
         
-        # Create worktree structure
-        worktree_rvs_dir = worktree_path / '.rvs'
-        worktree_rvs_dir.mkdir(exist_ok=True)
+        # Create worktree structure (Git-like)
+        # 1. Create worktree metadata directory in main repo
+        worktrees_dir = self.repo.rvs_dir / 'worktrees'
+        worktrees_dir.mkdir(exist_ok=True)
         
-        # Create gitdir file pointing to main repository
-        gitdir_file = worktree_path / '.rvs' / 'gitdir'
+        worktree_name = worktree_path.name
+        worktree_metadata_dir = worktrees_dir / worktree_name
+        worktree_metadata_dir.mkdir(exist_ok=True)
+        
+        # 2. Create .rvs file in worktree (pointing to metadata directory)
+        rvs_file = worktree_path / '.rvs'
+        with open(rvs_file, 'w') as f:
+            f.write(f"rvsdir: {worktree_metadata_dir}")
+        
+        # 3. Create gitdir file in metadata directory (pointing back to main repo)
+        gitdir_file = worktree_metadata_dir / 'gitdir'
         with open(gitdir_file, 'w') as f:
             f.write(str(self.repo.rvs_dir))
         
-        # Create HEAD file
-        head_file = worktree_path / '.rvs' / 'HEAD'
+        # 4. Create HEAD file in metadata directory
+        head_file = worktree_metadata_dir / 'HEAD'
         if detach or not branch_name:
             with open(head_file, 'w') as f:
                 f.write(commit_hash)
@@ -147,10 +157,10 @@ class WorktreeCommand(BaseCommand):
                 f.write(f"ref: refs/heads/{branch_name}")
         
         # Checkout files to worktree
-        self._checkout_files_to_worktree(commit_hash, worktree_path)
+        checked_out_files = self._checkout_files_to_worktree(commit_hash, worktree_path)
         
-        # Register worktree
-        self._register_worktree(worktree_path, branch_name, commit_hash)
+        # Create index for worktree that matches the checked out files
+        self._create_worktree_index(worktree_metadata_dir, checked_out_files)
         
         if detach:
             print(f"Prepared worktree (detached HEAD {commit_hash[:8]})")
@@ -204,9 +214,9 @@ class WorktreeCommand(BaseCommand):
         if not wt_path.exists():
             raise RVSError(f"'{worktree_path}' does not exist")
         
-        # Check if it's a valid worktree
-        gitdir_file = wt_path / '.rvs' / 'gitdir'
-        if not gitdir_file.exists():
+        # Check if it's a valid worktree (has .rvs file)
+        rvs_file = wt_path / '.rvs'
+        if not rvs_file.is_file():
             raise RVSError(f"'{worktree_path}' is not a working tree")
         
         # Check if worktree is locked
@@ -251,31 +261,52 @@ class WorktreeCommand(BaseCommand):
     def lock_worktree(self, worktree_path: str, reason: Optional[str] = None):
         """Lock a working tree."""
         wt_path = Path(worktree_path).resolve()
-        lock_file = wt_path / '.rvs' / 'locked'
+        rvs_file = wt_path / '.rvs'
         
-        with open(lock_file, 'w') as f:
-            if reason:
-                f.write(reason)
+        if rvs_file.is_file():
+            with open(rvs_file, 'r') as f:
+                content = f.read().strip()
+                if content.startswith('rvsdir: '):
+                    metadata_dir = Path(content[8:])
+                    lock_file = metadata_dir / 'locked'
+                    
+                    with open(lock_file, 'w') as f:
+                        if reason:
+                            f.write(reason)
+                    
+                    print(f"Locked worktree '{worktree_path}'")
+                    return
         
-        print(f"Locked worktree '{worktree_path}'")
+        raise RVSError(f"'{worktree_path}' is not a valid worktree")
     
     def unlock_worktree(self, worktree_path: str):
         """Unlock a working tree."""
         wt_path = Path(worktree_path).resolve()
-        lock_file = wt_path / '.rvs' / 'locked'
+        rvs_file = wt_path / '.rvs'
         
-        if lock_file.exists():
-            lock_file.unlink()
-            print(f"Unlocked worktree '{worktree_path}'")
-        else:
-            print(f"Worktree '{worktree_path}' is not locked")
+        if rvs_file.is_file():
+            with open(rvs_file, 'r') as f:
+                content = f.read().strip()
+                if content.startswith('rvsdir: '):
+                    metadata_dir = Path(content[8:])
+                    lock_file = metadata_dir / 'locked'
+                    
+                    if lock_file.exists():
+                        lock_file.unlink()
+                        print(f"Unlocked worktree '{worktree_path}'")
+                    else:
+                        print(f"Worktree '{worktree_path}' is not locked")
+                    return
+        
+        raise RVSError(f"'{worktree_path}' is not a valid worktree")
     
     def _checkout_files_to_worktree(self, commit_hash: str, worktree_path: Path):
         """Checkout files from commit to worktree."""
+        checked_out_files = {}
         try:
             obj_type, content = self.repo._read_object(commit_hash)
             if obj_type != "commit":
-                return
+                return checked_out_files
             
             import json
             commit_data = json.loads(content.decode('utf-8'))
@@ -283,47 +314,52 @@ class WorktreeCommand(BaseCommand):
             tree_files = self.repo._read_tree(tree_hash)
             
             for file_path, file_hash in tree_files.items():
-                self._restore_file_to_worktree(file_path, file_hash, worktree_path)
+                if self._restore_file_to_worktree(file_path, file_hash, worktree_path):
+                    checked_out_files[file_path] = file_hash
                 
         except Exception as e:
             print(f"Warning: Could not checkout files: {e}")
+        
+        return checked_out_files
     
     def _restore_file_to_worktree(self, file_path: str, file_hash: str, worktree_path: Path):
         """Restore a file to specific worktree."""
         try:
             obj_type, content = self.repo._read_object(file_hash)
             if obj_type != "blob":
-                return
+                return False
             
             full_path = worktree_path / file_path
             full_path.parent.mkdir(parents=True, exist_ok=True)
             
             with open(full_path, 'wb') as f:
                 f.write(content)
+            
+            return True
                 
         except Exception:
-            pass
+            return False
     
-    def _register_worktree(self, worktree_path: Path, branch: Optional[str], commit: str):
-        """Register a new worktree."""
-        worktrees_dir = self.repo.rvs_dir / 'worktrees'
-        worktrees_dir.mkdir(exist_ok=True)
+    def _create_worktree_index(self, worktree_metadata_dir: Path, checked_out_files: dict):
+        """Create an index file for the worktree that matches the checked out files."""
+        from ..core.index import Index
         
-        # Create worktree info file
-        wt_name = worktree_path.name
-        wt_info_dir = worktrees_dir / wt_name
-        wt_info_dir.mkdir(exist_ok=True)
+        # Create index in the worktree metadata directory
+        # We need to create a temporary repo path for the Index class
+        # The Index class expects the repo path, but we want to save to a specific location
+        index_file = worktree_metadata_dir / 'index'
         
-        # Write gitdir file
-        with open(wt_info_dir / 'gitdir', 'w') as f:
-            f.write(str(worktree_path / '.rvs'))
+        # Convert checked_out_files to the format expected by Index
+        entries = {}
+        for file_path, file_hash in checked_out_files.items():
+            entries[file_path] = {'obj_hash': file_hash}
         
-        # Write HEAD file
-        with open(wt_info_dir / 'HEAD', 'w') as f:
-            if branch:
-                f.write(f"ref: refs/heads/{branch}")
-            else:
-                f.write(commit)
+        # Save the index directly to the metadata directory
+        import json
+        with open(index_file, 'w', encoding='utf-8') as f:
+            json.dump(entries, f, indent=2)
+    
+
     
     def _unregister_worktree(self, worktree_path: Path):
         """Unregister a worktree."""
@@ -380,8 +416,16 @@ class WorktreeCommand(BaseCommand):
     
     def _is_worktree_locked(self, worktree_path: Path) -> bool:
         """Check if worktree is locked."""
-        lock_file = worktree_path / '.rvs' / 'locked'
-        return lock_file.exists()
+        # For new-style worktrees, check in the metadata directory
+        rvs_file = worktree_path / '.rvs'
+        if rvs_file.is_file():
+            with open(rvs_file, 'r') as f:
+                content = f.read().strip()
+                if content.startswith('rvsdir: '):
+                    metadata_dir = Path(content[8:])
+                    lock_file = metadata_dir / 'locked'
+                    return lock_file.exists()
+        return False
     
     def _resolve_commit(self, commit_ish: str) -> str:
         """Resolve commit-ish to commit hash."""
