@@ -17,19 +17,73 @@ class RVS:
     
     def __init__(self, repo_path: str = "."):
         self.repo_path = Path(repo_path).resolve()
-        self.rvs_dir = self.repo_path / ".rvs"
-        self.objects_dir = self.rvs_dir / "objects"
-        self.refs_dir = self.rvs_dir / "refs"
-        self.heads_dir = self.refs_dir / "heads"
-        self.index_file = self.rvs_dir / "index"
-        self.head_file = self.rvs_dir / "HEAD"
-        self.config_file = self.rvs_dir / "config"
+        rvs_path = self.repo_path / ".rvs"
+        
+        # Check if this is a worktree (where .rvs is a file, not a directory)
+        if rvs_path.is_file():
+            # This is a worktree - read the rvsdir path from the .rvs file
+            with open(rvs_path, 'r') as f:
+                content = f.read().strip()
+                if content.startswith('rvsdir: '):
+                    worktree_metadata_dir = Path(content[8:])  # Remove 'rvsdir: ' prefix
+                else:
+                    raise RepositoryError(f"Invalid .rvs file format: {content}")
+            
+            # The worktree metadata directory contains HEAD, index, etc.
+            self.worktree_metadata_dir = worktree_metadata_dir
+            
+            # Read the main repository path from the gitdir file in worktree metadata
+            gitdir_file = worktree_metadata_dir / "gitdir"
+            if gitdir_file.exists():
+                with open(gitdir_file, 'r') as f:
+                    main_rvs_dir = Path(f.read().strip())
+            else:
+                raise RepositoryError("Worktree gitdir file not found")
+            
+            # Use main repository for objects, refs, etc.
+            self.main_rvs_dir = main_rvs_dir
+            self.rvs_dir = main_rvs_dir  # For compatibility
+            self.objects_dir = main_rvs_dir / "objects"
+            self.refs_dir = main_rvs_dir / "refs"
+            self.heads_dir = self.refs_dir / "heads"
+            self.index_file = worktree_metadata_dir / "index"  # Worktree has its own index
+            self.head_file = worktree_metadata_dir / "HEAD"    # Worktree has its own HEAD
+            self.config_file = main_rvs_dir / "config"
+            self.is_worktree = True
+        elif rvs_path.is_dir():
+            # This is a main repository
+            self.main_rvs_dir = rvs_path
+            self.rvs_dir = rvs_path
+            self.objects_dir = rvs_path / "objects"
+            self.refs_dir = rvs_path / "refs"
+            self.heads_dir = self.refs_dir / "heads"
+            self.index_file = rvs_path / "index"
+            self.head_file = rvs_path / "HEAD"
+            self.config_file = rvs_path / "config"
+            self.is_worktree = False
+        else:
+            # .rvs doesn't exist
+            self.main_rvs_dir = rvs_path
+            self.rvs_dir = rvs_path
+            self.objects_dir = rvs_path / "objects"
+            self.refs_dir = rvs_path / "refs"
+            self.heads_dir = self.refs_dir / "heads"
+            self.index_file = rvs_path / "index"
+            self.head_file = rvs_path / "HEAD"
+            self.config_file = rvs_path / "config"
+            self.is_worktree = False
+        
         self.hooks = Hook(self.repo_path)
     
     def _ensure_repo_exists(self):
         """Check if repository exists and raise error if not."""
-        if not self.rvs_dir.exists():
+        rvs_path = self.repo_path / ".rvs"
+        if not rvs_path.exists():
             raise RepositoryError("Not a RVS repository. Run 'rvs init' first.")
+        
+        # For worktrees, also check that the main repository exists
+        if self.is_worktree and not self.main_rvs_dir.exists():
+            raise RepositoryError("Main repository not found. Worktree may be corrupted.")
     
     def _hash_content(self, content: bytes) -> str:
         """Generate SHA-1 hash for content."""
@@ -74,22 +128,58 @@ class RVS:
     
     def _load_index(self) -> Dict[str, str]:
         """Load the staging area index using binary format."""
-        index = Index(self.repo_path)
-        entries = index.load()
+        if not self.index_file.exists():
+            return {}
         
-        # Convert to simple hash mapping for compatibility
-        return {path: data['obj_hash'] for path, data in entries.items()}
+        # For worktrees, we need to load the index directly from the metadata directory
+        if self.is_worktree:
+            import json
+            try:
+                with open(self.index_file, 'r', encoding='utf-8') as f:
+                    entries = json.load(f)
+                # Convert to simple hash mapping for compatibility
+                return {path: data['obj_hash'] for path, data in entries.items()}
+            except (IOError, json.JSONDecodeError):
+                return {}
+        else:
+            # For main repositories, use the Index class
+            index = Index(self.repo_path)
+            entries = index.load()
+            # Convert to simple hash mapping for compatibility
+            return {path: data['obj_hash'] for path, data in entries.items()}
     
     def _save_index(self, index: Dict[str, str]):
         """Save the staging area index using binary format."""
-        index_obj = Index(self.repo_path)
-        
         # Convert to full entry format
         entries = {}
         for path, obj_hash in index.items():
             entries[path] = {'obj_hash': obj_hash}
         
-        index_obj.save(entries)
+        # For worktrees, save directly to the metadata directory
+        if self.is_worktree:
+            import json
+            with open(self.index_file, 'w', encoding='utf-8') as f:
+                json.dump(entries, f, indent=2)
+        else:
+            # For main repositories, use the Index class
+            index_obj = Index(self.repo_path)
+            index_obj.save(entries)
+    
+    def _normalize_path(self, file_path: str) -> str:
+        """Normalize file path like Git does."""
+        # Convert to Path object and resolve relative components
+        path = Path(file_path)
+        
+        # Get the absolute path and make it relative to repo root
+        abs_path = (self.repo_path / path).resolve()
+        try:
+            rel_path = abs_path.relative_to(self.repo_path)
+            # Convert back to string with forward slashes (Git style)
+            normalized = str(rel_path).replace('\\', '/')
+            return normalized
+        except ValueError:
+            # Path is outside repo, return as-is
+            return file_path
     
     def _get_file_hash(self, file_path: Path) -> str:
         """Get hash of a file's content."""
@@ -165,8 +255,10 @@ class RVS:
                 continue
             
             if full_path.is_file():
+                # Normalize the path (remove ./ prefix, resolve relative paths)
+                normalized_path = self._normalize_path(file_path)
                 file_hash = self._get_file_hash(full_path)
-                index[file_path] = file_hash
+                index[normalized_path] = file_hash
                 # Git add is silent by default
             elif full_path.is_dir():
                 # Recursively add all files in the directory
@@ -198,13 +290,14 @@ class RVS:
         working_files = set()
         for file_path in dir_path.rglob('*'):
             if file_path.is_file():
-                # Skip .rvs directory and its contents
-                if str(file_path).startswith(str(self.rvs_dir)):
-                    continue
-                
                 # Get relative path from repo root
                 rel_path = file_path.relative_to(self.repo_path)
-                rel_path_str = str(rel_path)
+                rel_path_str = str(rel_path).replace('\\', '/')  # Normalize path separators
+                
+                # Skip .rvs file/directory and its contents
+                if rel_path_str == '.rvs' or rel_path_str.startswith('.rvs/'):
+                    continue
+                
                 working_files.add(rel_path_str)
                 
                 # Add to index
@@ -296,9 +389,15 @@ class RVS:
         # Get all files in working directory
         working_files = {}
         for file_path in self.repo_path.rglob('*'):
-            if file_path.is_file() and not str(file_path).startswith(str(self.rvs_dir)):
+            if file_path.is_file():
                 rel_path = file_path.relative_to(self.repo_path)
-                working_files[str(rel_path)] = self._get_file_hash(file_path)
+                rel_path_str = str(rel_path).replace('\\', '/')  # Normalize path separators
+                
+                # Skip .rvs file/directory and its contents
+                if rel_path_str == '.rvs' or rel_path_str.startswith('.rvs/'):
+                    continue
+                
+                working_files[rel_path_str] = self._get_file_hash(file_path)
         
         # Categorize files
         staged_files = set(index.keys())
@@ -468,10 +567,24 @@ class RVS:
         
         if head_content.startswith("ref: refs/heads/"):
             return head_content[16:]  # Remove "ref: refs/heads/"
+        
+        # For worktrees, if HEAD contains a commit hash, we're in detached HEAD state
+        if self.is_worktree and len(head_content) == 40:  # SHA-1 hash length
+            return "HEAD"  # Detached HEAD
+        
         return "main"
     
     def _get_branch_commit(self, branch: str) -> Optional[str]:
         """Get the latest commit hash for a branch."""
+        # Special case for detached HEAD in worktrees
+        if self.is_worktree and branch == "HEAD":
+            if self.head_file.exists():
+                with open(self.head_file, 'r') as f:
+                    head_content = f.read().strip()
+                    # If it's a commit hash (not a ref), return it
+                    if not head_content.startswith("ref: ") and len(head_content) == 40:
+                        return head_content
+        
         branch_file = self.heads_dir / branch
         if not branch_file.exists():
             return None
@@ -526,9 +639,15 @@ class RVS:
             # Get all files in working directory
             working_files = {}
             for file_path in self.repo_path.rglob('*'):
-                if file_path.is_file() and not str(file_path).startswith(str(self.rvs_dir)):
+                if file_path.is_file():
                     rel_path = file_path.relative_to(self.repo_path)
-                    working_files[str(rel_path)] = self._get_file_hash(file_path)
+                    rel_path_str = str(rel_path).replace('\\', '/')  # Normalize path separators
+                    
+                    # Skip .rvs file/directory and its contents
+                    if rel_path_str == '.rvs' or rel_path_str.startswith('.rvs/'):
+                        continue
+                    
+                    working_files[rel_path_str] = self._get_file_hash(file_path)
             
             # Find untracked files
             untracked_files = []
